@@ -78,9 +78,9 @@ tree_cell * nasl_bn_cmp(lex_ctxt* lexic)
   key1 = BN_new();
   key2 = BN_new();
 
-  if (BN_bin2bn((const char*)s1, sz1, key1) == 0)
+  if (BN_bin2bn((const unsigned char*)s1, sz1, key1) == 0)
     goto fail;
-  if (BN_bin2bn((const char*)s2, sz2, key2) == 0)
+  if (BN_bin2bn((const unsigned char*)s2, sz2, key2) == 0)
     goto fail;
 
   retc->x.i_val = BN_cmp(key1,key2);
@@ -119,7 +119,7 @@ tree_cell * nasl_bn_random(lex_ctxt* lexic)
   if (s1 == NULL)
      goto fail;
 
-  BN_bn2bin(key, s1);
+  BN_bn2bin(key, (unsigned char*)s1);
 
   if (s1[0] & 0x80)
     len = 1;
@@ -149,7 +149,7 @@ tree_cell * nasl_pem_to(lex_ctxt* lexic, int type)
   RSA * rsa = NULL;
   DSA * dsa = NULL;
   BIGNUM * key = NULL;
-  BIO * bio;
+  BIO * bio = NULL;
   long privlen, plen, s1len;
   int len;
 
@@ -193,7 +193,7 @@ tree_cell * nasl_pem_to(lex_ctxt* lexic, int type)
   if (s1 == NULL)
      goto fail;
 
-  BN_bn2bin(key, s1);
+  BN_bn2bin(key, (unsigned char*)s1);
   
   if (s1[0] & 0x80)
     len = 1;
@@ -265,11 +265,11 @@ tree_cell * nasl_dh_generate_key(lex_ctxt* lexic)
   dh->priv_key = BN_new();
   
 
-  if (BN_bin2bn((const char*)s1, sz1, dh->p) == 0)
+  if (BN_bin2bn((const unsigned char*)s1, sz1, dh->p) == 0)
      goto fail;
-  if (BN_bin2bn((const char*)s2, sz2, dh->g) == 0)
+  if (BN_bin2bn((const unsigned char*)s2, sz2, dh->g) == 0)
      goto fail;
-  if (BN_bin2bn((const char*)s3, sz3, dh->priv_key) == 0)
+  if (BN_bin2bn((const unsigned char*)s3, sz3, dh->priv_key) == 0)
      goto fail;
 
   if (dh->p == NULL)
@@ -282,7 +282,7 @@ tree_cell * nasl_dh_generate_key(lex_ctxt* lexic)
   pub = emalloc(pubsize); 
   if (pub == NULL)
      goto fail;
-  BN_bn2bin(dh->pub_key, pub);
+  BN_bn2bin(dh->pub_key, (unsigned char*)pub);
 
   if (pub[0] & 0x80)
     len = 1;
@@ -351,20 +351,20 @@ tree_cell * nasl_dh_compute_key(lex_ctxt* lexic)
   dh->priv_key = BN_new();
   dh_server_pub = BN_new();
 
-  if (BN_bin2bn((const char*)s1, sz1, dh->p) == 0)
+  if (BN_bin2bn((const unsigned char*)s1, sz1, dh->p) == 0)
      goto fail;
-  if (BN_bin2bn((const char*)s2, sz2, dh->g) == 0)
+  if (BN_bin2bn((const unsigned char*)s2, sz2, dh->g) == 0)
      goto fail;
-  if (BN_bin2bn((const char*)s3, sz3, dh_server_pub) == 0)
+  if (BN_bin2bn((const unsigned char*)s3, sz3, dh_server_pub) == 0)
      goto fail;
-  if (BN_bin2bn((const char*)s4, sz4, dh->pub_key) == 0)
+  if (BN_bin2bn((const unsigned char*)s4, sz4, dh->pub_key) == 0)
      goto fail;
-  if (BN_bin2bn((const char*)s5, sz5, dh->priv_key) == 0)
+  if (BN_bin2bn((const unsigned char*)s5, sz5, dh->priv_key) == 0)
      goto fail;
 
   klen = DH_size(dh);
   kbuf = emalloc(klen);
-  kout = DH_compute_key(kbuf, dh_server_pub, dh);
+  kout = DH_compute_key((unsigned char*)kbuf, dh_server_pub, dh);
  
   if (kbuf[0] & 0x80)
     len = 1;
@@ -419,16 +419,16 @@ tree_cell * nasl_rsa_public_decrypt(lex_ctxt* lexic)
   rsa->e = BN_new();
   rsa->n = BN_new();
 
-  if (BN_bin2bn((const char*)s3, sz3, rsa->n) == 0)
+  if (BN_bin2bn((const unsigned char*)s3, sz3, rsa->n) == 0)
     goto fail;
-  if (BN_bin2bn((const char*)s2, sz2, rsa->e) == 0)
+  if (BN_bin2bn((const unsigned char*)s2, sz2, rsa->e) == 0)
     goto fail;
 
   decrypted = emalloc(sz1);
   if (!decrypted)
     goto fail;
 
-  if ((len = RSA_public_decrypt(sz1, s1, decrypted, rsa,
+  if ((len = RSA_public_decrypt(sz1, (unsigned char*)s1, (unsigned char*)decrypted, rsa,
 	    RSA_PKCS1_PADDING)) < 0)
     goto fail;
 
@@ -450,8 +450,9 @@ tree_cell * nasl_rsa_sign(lex_ctxt* lexic)
   char *s1 = NULL,*s2 = NULL,*s3 = NULL, *s4 = NULL, *sig = NULL, *signature = NULL;
   tree_cell	*retc = NULL;
   RSA *rsa = NULL;
-  int len, ok;
+  int ok;
   long sz1, sz2, sz3, sz4, slen;
+  unsigned int len;
 
   if ( check_authenticated(lexic) < 0 ) return FAKE_CELL;
 
@@ -484,11 +485,11 @@ tree_cell * nasl_rsa_sign(lex_ctxt* lexic)
   rsa->n = BN_new();
   rsa->d = BN_new();
 
-  if (BN_bin2bn((const char*)s3, sz3, rsa->n) == 0)
+  if (BN_bin2bn((const unsigned char*)s3, sz3, rsa->n) == 0)
     goto fail;
-  if (BN_bin2bn((const char*)s2, sz2, rsa->e) == 0)
+  if (BN_bin2bn((const unsigned char*)s2, sz2, rsa->e) == 0)
     goto fail;
-  if (BN_bin2bn((const char*)s4, sz4, rsa->d) == 0)
+  if (BN_bin2bn((const unsigned char*)s4, sz4, rsa->d) == 0)
     goto fail;
 
   slen = RSA_size(rsa);
@@ -496,7 +497,7 @@ tree_cell * nasl_rsa_sign(lex_ctxt* lexic)
   if (!sig)
     goto fail;
 
-  ok = RSA_sign(NID_sha1, s1, sz1, sig, &len, rsa);
+  ok = RSA_sign(NID_sha1, (unsigned char*)s1, sz1, (unsigned char*)sig, &len, rsa);
   if (!ok || len > slen)
     goto fail;
   
@@ -545,13 +546,13 @@ tree_cell * nasl_bf_cbc(lex_ctxt* lexic, int enc)
 	goto fail;
 
   /* key len = 16 : { "blowfish-cbc", 	SSH_CIPHER_SSH2, 8, 16, EVP_bf_cbc }*/
-  BF_set_key(&key, 16, enckey);
+  BF_set_key(&key, 16, (unsigned char*)enckey);
 
   out = emalloc(datalen);
   if (!out)
     goto fail;
 
-  BF_cbc_encrypt(data, out, datalen, &key, iv, enc);
+  BF_cbc_encrypt((unsigned char*)data, (unsigned char*)out, datalen, &key, (unsigned char*)iv, enc);
 
   retc->type = DYN_ARRAY;
   retc->x.ref_val = a = emalloc(sizeof(nasl_array));
@@ -559,14 +560,14 @@ tree_cell * nasl_bf_cbc(lex_ctxt* lexic, int enc)
   /* first encrypted */
   v.var_type = VAR2_DATA;
   v.v.v_str.s_siz = datalen;
-  v.v.v_str.s_val = out;
+  v.v.v_str.s_val = (unsigned char*)out;
   (void) add_var_to_list(a, 0, &v);
   free(out);
 
   /* second iv */
   v.var_type = VAR2_DATA;
   v.v.v_str.s_siz = ivlen;
-  v.v.v_str.s_val = iv;
+  v.v.v_str.s_val = (unsigned char*)iv;
   (void) add_var_to_list(a, 1, &v);
 
   goto ret;
@@ -630,20 +631,20 @@ tree_cell * nasl_dsa_do_verify(lex_ctxt* lexic)
   if ((sig = DSA_SIG_new()) == NULL)
     goto fail;
   
-  if (BN_bin2bn((const char*)p, plen, dsa->p) == 0)
+  if (BN_bin2bn((const unsigned char*)p, plen, dsa->p) == 0)
      goto fail;
-  if (BN_bin2bn((const char*)g, glen, dsa->g) == 0)
+  if (BN_bin2bn((const unsigned char*)g, glen, dsa->g) == 0)
      goto fail;
-  if (BN_bin2bn((const char*)q, qlen, dsa->q) == 0)
+  if (BN_bin2bn((const unsigned char*)q, qlen, dsa->q) == 0)
      goto fail;
-  if (BN_bin2bn((const char*)pub, publen, dsa->pub_key) == 0)
+  if (BN_bin2bn((const unsigned char*)pub, publen, dsa->pub_key) == 0)
      goto fail;
-  if (BN_bin2bn((const char*)r, rlen, sig->r) == 0)
+  if (BN_bin2bn((const unsigned char*)r, rlen, sig->r) == 0)
      goto fail;
-  if (BN_bin2bn((const char*)s, slen, sig->s) == 0)
+  if (BN_bin2bn((const unsigned char*)s, slen, sig->s) == 0)
      goto fail;
 
-  if (DSA_do_verify(data, datalen, sig, dsa))
+  if (DSA_do_verify((unsigned char*)data, datalen, sig, dsa))
      retc->x.i_val = 1;
   
 fail:
@@ -710,18 +711,18 @@ tree_cell * nasl_dsa_do_sign(lex_ctxt* lexic)
   dsa->pub_key = BN_new();
   dsa->priv_key = BN_new();
   
-  if (BN_bin2bn((const char*)p, plen, dsa->p) == 0)
+  if (BN_bin2bn((const unsigned char*)p, plen, dsa->p) == 0)
      goto fail;
-  if (BN_bin2bn((const char*)g, glen, dsa->g) == 0)
+  if (BN_bin2bn((const unsigned char*)g, glen, dsa->g) == 0)
      goto fail;
-  if (BN_bin2bn((const char*)q, qlen, dsa->q) == 0)
+  if (BN_bin2bn((const unsigned char*)q, qlen, dsa->q) == 0)
      goto fail;
-  if (BN_bin2bn((const char*)pub, publen, dsa->pub_key) == 0)
+  if (BN_bin2bn((const unsigned char*)pub, publen, dsa->pub_key) == 0)
      goto fail;
-  if (BN_bin2bn((const char*)priv, privlen, dsa->priv_key) == 0)
+  if (BN_bin2bn((const unsigned char*)priv, privlen, dsa->priv_key) == 0)
      goto fail;
 
-  sig = DSA_do_sign(data, datalen, dsa);
+  sig = DSA_do_sign((unsigned char*)data, datalen, dsa);
   if (!sig)
     goto fail;  
 
@@ -733,8 +734,8 @@ tree_cell * nasl_dsa_do_sign(lex_ctxt* lexic)
   if (rlen > INTBLOB_LEN || slen > INTBLOB_LEN)
     goto fail;
 
-  BN_bn2bin(sig->r, sigblob+ SIGBLOB_LEN - INTBLOB_LEN - rlen);
-  BN_bn2bin(sig->s, sigblob+ SIGBLOB_LEN - slen);
+  BN_bn2bin(sig->r, (unsigned char*)(sigblob+ SIGBLOB_LEN - INTBLOB_LEN - rlen));
+  BN_bn2bin(sig->s, (unsigned char*)(sigblob+ SIGBLOB_LEN - slen));
   
   retc->x.str_val = sigblob;
   retc->size = SIGBLOB_LEN;
@@ -800,7 +801,7 @@ int generate_signed_script(char * filename)
  RSA * rsa = NULL;
  FILE * fp = fopen(NESSUS_STATE_DIR "/nessus/nessus_org.priv.pem", "r");
  unsigned char  * result;
- int len;
+ unsigned int len;
  int i;
  char md[SHA_DIGEST_LENGTH+1];
  int be_len;
@@ -822,7 +823,7 @@ int generate_signed_script(char * filename)
 
 
 
- SHA1(msg, msg_len + sizeof(msg_len), md);
+ SHA1((unsigned char*)msg, msg_len + sizeof(msg_len), (unsigned char*)md);
  if ( fp == NULL ) 
 	{
 	perror("open ");
@@ -840,7 +841,7 @@ int generate_signed_script(char * filename)
  len = RSA_size(rsa);
  result = emalloc(len);
 	
- RSA_sign(NID_sha1, md, SHA_DIGEST_LENGTH, result, &len, rsa);
+ RSA_sign(NID_sha1, (unsigned char*)md, SHA_DIGEST_LENGTH, (unsigned char*)result, &len, rsa);
  printf("#TRUSTED ");
  for ( i = 0 ; i < len ; i ++ )
  {
@@ -910,7 +911,7 @@ int verify_script_signature(char * filename)
  be_len = htonl(msg_len);
  memcpy(t + msg_len, &be_len, sizeof(msg_len));
 
- SHA1(t, msg_len + sizeof(msg_len), md);
+ SHA1((unsigned char*)t, msg_len + sizeof(msg_len), md);
 
  sig_len = strlen(sig);
 
