@@ -216,34 +216,6 @@ tree_cell * http_put(lex_ctxt * lexic)
 }
 
 
-/*
- * Syntax :
- * http_recv_header(soc)
- */
-tree_cell * nasl_http_recv_headers(lex_ctxt * lexic)
-{
- tree_cell * retc;
- int soc = get_int_var_by_num(lexic, 0, -1);
- char * buf = NULL;
- int sz = 0;
-
- if(soc <= 0)
- {
-  nasl_perror(lexic, "http_recv_header(): syntax: http_recv_header(<soc>)\n");
-  return NULL;
- }
- 
- http_recv_headers(soc, &buf, &sz); 
- if ( buf == NULL || sz <= 0 )
- 	return NULL;
-
- retc = alloc_tree_cell(0, NULL);
- retc->type = CONST_DATA;
- retc->size = sz;
- retc->x.str_val = buf;
- return retc;
-}
-
 /*-------------------[ cgibin() ]--------------------------------*/
 
  
