@@ -98,6 +98,7 @@ static init_func libfuncs[] = {
   "open_sock_udp",      nasl_open_sock_udp,  1, { NULL },
   "open_priv_sock_tcp", nasl_open_priv_sock_tcp, 0, { "dport", "sport", "timeout", NULL },
   "open_priv_sock_udp", nasl_open_priv_sock_udp, 0, { "dport", "sport", NULL },
+  "socket_get_error", nasl_socket_get_error, 1, { NULL },
   
   "recv",		nasl_recv, 0, { "length", "min", "socket", "timeout", NULL },
   "recv_line",		nasl_recv_line, 0, { "length", "socket", "timeout", NULL },
@@ -116,8 +117,6 @@ static init_func libfuncs[] = {
   "http_delete", 	http_delete,	  0, {"data", "item", "port", NULL },
   "http_put", 		http_put,	  0, {"data", "item", "port", NULL },
   "http_close_socket",	http_close_socket, 0, { "socket", NULL },
-  "http_recv_headers", nasl_http_recv_headers, 1, { NULL },
-  
   
   "get_host_name",	get_hostname, 0, { NULL }, 
   "get_host_ip",        get_host_ip,  0, { NULL },
@@ -364,6 +363,12 @@ static struct {
 
   "MSG_OOB", MSG_OOB,
 
+  "NOERR",      NASL_ERR_NOERR,
+  "ETIMEDOUT",  NASL_ERR_ETIMEDOUT,
+  "ECONNRESET", NASL_ERR_ECONNRESET,
+  "EUNREACH",   NASL_ERR_EUNREACH,
+  "EUNKNOWN",   NASL_ERR_EUNKNOWN,
+
   NULL, 0, 
 };
 /* See also in exec.c:
