@@ -54,11 +54,10 @@ int str_match(const char* string, const char* pattern, int icase)
 
 
 
-#ifndef HAVE_MEMMEM
 /*
  * Slow replacement for memmem()
  */
-void * memmem(haystack, hl_len, needle, n_len)
+void * nasl_memmem(haystack, hl_len, needle, n_len)
  const void *  haystack;
  size_t hl_len;
  const void * needle;
@@ -68,6 +67,9 @@ void * memmem(haystack, hl_len, needle, n_len)
  char * nd = (char*)needle;
  int i;
 
+ if ( hl_len < n_len )
+	return NULL;
+
  for(i=0;i<=hl_len-n_len;i++)
  {
   if(hs[i] == nd[0])
@@ -81,6 +83,5 @@ void * memmem(haystack, hl_len, needle, n_len)
  }
  return(NULL);
 }
-#endif
 
 
